@@ -6,7 +6,7 @@ def timeit(func):
         t1 = time()
         result = func(*args, **kwargs)
         t2 = time()
-        print(f'{func.__name__!r} executed in {(t2 - t1):.4f}s')
+        print(f'{func.__name__!r} executed in {(t2 - t1)}s')
         return result
 
     return wrap_func
